@@ -9,7 +9,9 @@ mod description;
 mod error;
 mod helpers;
 mod from;
+#[macro_use]
+mod extend;
 
 pub use description::*;
 pub use error::*;
-pub use helpers::*;
+pub use helpers::*;
\ No newline at end of file
